=begin
#CryptoAPIs

#Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.

The version of the OpenAPI document: 2.0.0
Contact: developers@cryptoapis.io
Generated by: https://openapi-generator.tech
OpenAPI Generator version: 5.2.1-SNAPSHOT

=end

require 'date'
require 'time'

module CryptoApis
  # Defines an `item` as one result.
  class CoinsForwardingSuccessDataItem
    # Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
    attr_accessor :blockchain

    # Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\", \"rinkeby\" are test networks.
    attr_accessor :network

    # Represents the hash of the address that provides the coins.
    attr_accessor :from_address

    # Represents the hash of the address to forward the coins to.
    attr_accessor :to_address

    # Represents the amount of coins that have been forwarded.
    attr_accessor :forwarded_amount

    # Represents the unit of coins that have been forwarded, e.g. BTC.
    attr_accessor :forwarded_unit

    # Represents the amount of the fee spent for the coins to be forwarded.
    attr_accessor :spent_fees_amount

    # Represents the unit of the fee spent for the coins to be forwarded, e.g. BTC.
    attr_accessor :spent_fees_unit

    # Defines the unique Transaction ID that triggered the coin forwarding.
    attr_accessor :trigger_transaction_id

    # Defines the unique Transaction ID that forwarded the coins.
    attr_accessor :forwarding_transaction_id

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        :'blockchain' => :'blockchain',
        :'network' => :'network',
        :'from_address' => :'fromAddress',
        :'to_address' => :'toAddress',
        :'forwarded_amount' => :'forwardedAmount',
        :'forwarded_unit' => :'forwardedUnit',
        :'spent_fees_amount' => :'spentFeesAmount',
        :'spent_fees_unit' => :'spentFeesUnit',
        :'trigger_transaction_id' => :'triggerTransactionId',
        :'forwarding_transaction_id' => :'forwardingTransactionId'
      }
    end

    # Returns all the JSON keys this model knows about
    def self.acceptable_attributes
      attribute_map.values
    end

    # Attribute type mapping.
    def self.openapi_types
      {
        :'blockchain' => :'String',
        :'network' => :'String',
        :'from_address' => :'String',
        :'to_address' => :'String',
        :'forwarded_amount' => :'String',
        :'forwarded_unit' => :'String',
        :'spent_fees_amount' => :'String',
        :'spent_fees_unit' => :'String',
        :'trigger_transaction_id' => :'String',
        :'forwarding_transaction_id' => :'String'
      }
    end

    # List of attributes with nullable: true
    def self.openapi_nullable
      Set.new([
      ])
    end

    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    def initialize(attributes = {})
      if (!attributes.is_a?(Hash))
        fail ArgumentError, "The input argument (attributes) must be a hash in `CryptoApis::CoinsForwardingSuccessDataItem` initialize method"
      end

      # check to see if the attribute exists and convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h|
        if (!self.class.attribute_map.key?(k.to_sym))
          fail ArgumentError, "`#{k}` is not a valid attribute in `CryptoApis::CoinsForwardingSuccessDataItem`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
        end
        h[k.to_sym] = v
      }

      if attributes.key?(:'blockchain')
        self.blockchain = attributes[:'blockchain']
      end

      if attributes.key?(:'network')
        self.network = attributes[:'network']
      end

      if attributes.key?(:'from_address')
        self.from_address = attributes[:'from_address']
      end

      if attributes.key?(:'to_address')
        self.to_address = attributes[:'to_address']
      end

      if attributes.key?(:'forwarded_amount')
        self.forwarded_amount = attributes[:'forwarded_amount']
      end

      if attributes.key?(:'forwarded_unit')
        self.forwarded_unit = attributes[:'forwarded_unit']
      end

      if attributes.key?(:'spent_fees_amount')
        self.spent_fees_amount = attributes[:'spent_fees_amount']
      end

      if attributes.key?(:'spent_fees_unit')
        self.spent_fees_unit = attributes[:'spent_fees_unit']
      end

      if attributes.key?(:'trigger_transaction_id')
        self.trigger_transaction_id = attributes[:'trigger_transaction_id']
      end

      if attributes.key?(:'forwarding_transaction_id')
        self.forwarding_transaction_id = attributes[:'forwarding_transaction_id']
      end
    end

    # Show invalid properties with the reasons. Usually used together with valid?
    # @return Array for valid properties with the reasons
    def list_invalid_properties
      invalid_properties = Array.new
      if @blockchain.nil?
        invalid_properties.push('invalid value for "blockchain", blockchain cannot be nil.')
      end

      if @network.nil?
        invalid_properties.push('invalid value for "network", network cannot be nil.')
      end

      if @from_address.nil?
        invalid_properties.push('invalid value for "from_address", from_address cannot be nil.')
      end

      if @to_address.nil?
        invalid_properties.push('invalid value for "to_address", to_address cannot be nil.')
      end

      if @forwarded_amount.nil?
        invalid_properties.push('invalid value for "forwarded_amount", forwarded_amount cannot be nil.')
      end

      if @forwarded_unit.nil?
        invalid_properties.push('invalid value for "forwarded_unit", forwarded_unit cannot be nil.')
      end

      if @spent_fees_amount.nil?
        invalid_properties.push('invalid value for "spent_fees_amount", spent_fees_amount cannot be nil.')
      end

      if @spent_fees_unit.nil?
        invalid_properties.push('invalid value for "spent_fees_unit", spent_fees_unit cannot be nil.')
      end

      if @trigger_transaction_id.nil?
        invalid_properties.push('invalid value for "trigger_transaction_id", trigger_transaction_id cannot be nil.')
      end

      if @forwarding_transaction_id.nil?
        invalid_properties.push('invalid value for "forwarding_transaction_id", forwarding_transaction_id cannot be nil.')
      end

      invalid_properties
    end

    # Check to see if the all the properties in the model are valid
    # @return true if the model is valid
    def valid?
      return false if @blockchain.nil?
      return false if @network.nil?
      return false if @from_address.nil?
      return false if @to_address.nil?
      return false if @forwarded_amount.nil?
      return false if @forwarded_unit.nil?
      return false if @spent_fees_amount.nil?
      return false if @spent_fees_unit.nil?
      return false if @trigger_transaction_id.nil?
      return false if @forwarding_transaction_id.nil?
      true
    end

    # Checks equality by comparing each attribute.
    # @param [Object] Object to be compared
    def ==(o)
      return true if self.equal?(o)
      self.class == o.class &&
          blockchain == o.blockchain &&
          network == o.network &&
          from_address == o.from_address &&
          to_address == o.to_address &&
          forwarded_amount == o.forwarded_amount &&
          forwarded_unit == o.forwarded_unit &&
          spent_fees_amount == o.spent_fees_amount &&
          spent_fees_unit == o.spent_fees_unit &&
          trigger_transaction_id == o.trigger_transaction_id &&
          forwarding_transaction_id == o.forwarding_transaction_id
    end

    # @see the `==` method
    # @param [Object] Object to be compared
    def eql?(o)
      self == o
    end

    # Calculates hash code according to all attributes.
    # @return [Integer] Hash code
    def hash
      [blockchain, network, from_address, to_address, forwarded_amount, forwarded_unit, spent_fees_amount, spent_fees_unit, trigger_transaction_id, forwarding_transaction_id].hash
    end

    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def self.build_from_hash(attributes)
      new.build_from_hash(attributes)
    end

    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)
      self.class.openapi_types.each_pair do |key, type|
        if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
          self.send("#{key}=", nil)
        elsif type =~ /\AArray<(.*)>/i
          # check to ensure the input is an array given that the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
        end
      end

      self
    end

    # Deserializes the data based on type
    # @param string type Data type
    # @param string value Value to be deserialized
    # @return [Object] Deserialized data
    def _deserialize(type, value)
      case type.to_sym
      when :Time
        Time.parse(value)
      when :Date
        Date.parse(value)
      when :String
        value.to_s
      when :Integer
        value.to_i
      when :Float
        value.to_f
      when :Boolean
        if value.to_s =~ /\A(true|t|yes|y|1)\z/i
          true
        else
          false
        end
      when :Object
        # generic object (usually a Hash), return directly
        value
      when /\AArray<(?<inner_type>.+)>\z/
        inner_type = Regexp.last_match[:inner_type]
        value.map { |v| _deserialize(inner_type, v) }
      when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
        k_type = Regexp.last_match[:k_type]
        v_type = Regexp.last_match[:v_type]
        {}.tap do |hash|
          value.each do |k, v|
            hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
          end
        end
      else # model
        # models (e.g. Pet) or oneOf
        klass = CryptoApis.const_get(type)
        klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
      end
    end

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # to_body is an alias to to_hash (backward compatibility)
    # @return [Hash] Returns the object in the form of hash
    def to_body
      to_hash
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = self.send(attr)
        if value.nil?
          is_nullable = self.class.openapi_nullable.include?(attr)
          next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
        end

        hash[param] = _to_hash(value)
      end
      hash
    end

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end

  end

end
